 Reahl is a web application framework that allows a Python programmer to work in 
 terms of useful abstractions - using a single programming language.

 The reahl-component framework extends setuptools distribution packages to package
 and distribute more than just code.
